# General

Crafted user guides covering a specific topic. These are mostly used to explain advanced topics, that are too complex to fully explain in a tutorial, or are linked as "dive deeper" options to read up on something.

## Contents

:::{toctree}
:maxdepth: 1
:titlesonly:

general/best_practice.md
general/linking_components.md
general/common_errors.md
general/solvers.md
:::

## Format & Structure

Currently, the general topic user guides do not follow a specific format.
